@@ -12,16 +12,21 @@
  * Autoloader and dependency injection initialization for Swift Mailer.
  */
 
-if (defined('SWIFT_REQUIRED_LOADED'))
-	return;
+if (defined('SWIFT_REQUIRED_LOADED')) {
+    return;
+}
 
 define('SWIFT_REQUIRED_LOADED', true);
 
 //Load Swift utility class
 require dirname(__FILE__) . '/classes/Swift.php';
 
-//Start the autoloader
-Swift::registerAutoload();
+if (!function_exists('_swiftmailer_init')) {
+    function _swiftmailer_init()
+    {
+        require dirname(__FILE__) . '/swift_init.php';
+    }
+}
 
-//Load the init script to set up dependency injection
-require dirname(__FILE__) . '/swift_init.php';
+//Start the autoloader and lazy-load the init script to set up dependency injection
+Swift::registerAutoload('_swiftmailer_init');
